@@ -6,10 +6,10 @@ use 5.008001;
 use base qw( Exporter );
 use File::Spec;
 
-our @EXPORT_OK = qw( dist_share );
+our @EXPORT_OK = qw( dist_share dist_config );
 
 # ABSTRACT: Locate per-dist shared files
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 # TODO: Works with PAR
@@ -71,6 +71,23 @@ sub dist_share ($)
   return;
 }
 
+
+sub dist_config
+{
+  my($dist_name) = @_;
+  my $dir = dist_share $dist_name;
+  return {} unless defined $dir && -d $dir;
+  my $fn = File::Spec->catfile($dir, 'config.pl');
+  return {} unless -f $fn;
+  my $fh;
+  open($fh, '<', $fn) || die "unable to read $fn $!";
+  my $pl = do { local $/; <$fh> };
+  close $fh;
+  my $config = eval $pl;
+  die $@ if $@;
+  $config;
+}
+
 sub import
 {
   my($class, @args) = @_;
@@ -108,7 +125,7 @@ File::ShareDir::Dist - Locate per-dist shared files
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -219,6 +236,14 @@ it.
 
 Returns nothing if no share directory could be found.
 
+=head2 dist_config
+
+[version 0.07]
+
+ my $config = dist_config $dist_name;
+
+Returns the config at runtime as created by L<File::ShareDir::Dist::Install> and install time.
+
 =head1 ENVIRONMENT
 
 =over 4
@@ -238,7 +263,11 @@ caveats or features depending on your perspective I suppose.
 
 =over
 
-=item L<File::ShareDir>
+=item L<File::ShareDir::Dist::Install>
+
+=item L<App::Prove::Plugin::ShareDirDist>
+
+=item L<App::Yath::Plugin::ShareDirDist>
 
 =back
 
@@ -252,7 +281,7 @@ Yanick Champoux (yanick)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Graham Ollis.
+This software is copyright (c) 2017,2018 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
